call method

BigInt call()

Returns the next random number in the range 0, max.

This returns a BigInt instead of an Int64 to guarantee that all results will be non-negative.

Callers that don't care about the sign of the result and care only about the random bits can call nextInt64 instead, which is faster.

Implementation

BigInt call() => nextInt64().toUnsignedBigInt();